@@ -9,7 +9,7 @@ https://raw.github.com/bengillies/chrjs.store/master/dist/chrjs-store-latest.js
  *
  * Dependencies: chrjs library, jQuery, TiddlySpace
  *
- * Version: 0.6.3
+ * Version: 0.6.6
  *
  * created by Ben Gillies
  * Chrjs-Store is distributed under a BSD License
@@ -1089,8 +1089,8 @@ define('localStore',['cache'], function(cache) {
 			} else if (!tiddler.bag) {
 				tidTester = $.extend(new tiddlyweb.Tiddler(), tiddler);
 				for (i = 0, l = bagList.length; i < l; i++) {
-					tiddler.bag = bagList[i];
-					match = store[createKey(tiddler)];
+					tidTester.bag = bagList[i];
+					match = store[createKey(tidTester)];
 					if (match) {
 						return makeCopy(match);
 					}
@@ -1443,17 +1443,19 @@ return function(tiddlerCallback, getCached, defaultContainers) {
 		};
 	});
 
-	var defaults = host(defaultContainers);
+	var defaults = host(defaultContainers),
+		containers = refresh(ev);
 	$.extend(self, {
 		recipe: null,
 		getDefaults: function(callback) {
 			// callback is optional and either gets passed or returns an object with:
 			// pullFrom: default location to refresh the store from
 			// pushTo: default location to save to
-			var res = defaults.getDefault(function(containers) {
-				self.recipe = containers.pullFrom;
+			var res = defaults.getDefault(function(defaults) {
+				self.recipe = defaults.pullFrom;
+				containers.set(store, defaults.pullFrom);
 				if (callback) {
-					callback(containers);
+					callback(defaults);
 				}
 			});
 
@@ -1461,15 +1463,16 @@ return function(tiddlerCallback, getCached, defaultContainers) {
 		}
 	});
 
-	var containers = refresh(ev);
 	$.extend(self, {
 		refresh: function(callback) {
-			containers.refresh(function(tiddlers) {
-				if (tiddlers) {
-					callback.call(self, collection(self, tiddlers));
-				} else {
-					callback.apply(self, arguments);
-				}
+			self.getDefaults(function() {
+				containers.refresh(function(tiddlers) {
+					if (tiddlers) {
+						callback.call(self, collection(self, tiddlers));
+					} else {
+						callback.apply(self, arguments);
+					}
+				});
 			});
 
 			return self;
